You are viewing a plain text version of this content. The canonical link for it is here.
Posted to java-dev@axis.apache.org by st...@apache.org on 2005/10/28 16:41:45 UTC

svn commit: r329217 - in /webservices/axis2/trunk/java/modules/core: src/org/apache/axis2/deployment/ src/org/apache/axis2/description/ src/org/apache/axis2/engine/ src/org/apache/axis2/storage/impl/ test/org/apache/axis2/deployment/

Author: stevel
Date: Fri Oct 28 07:41:32 2005
New Revision: 329217

URL: http://svn.apache.org/viewcvs?rev=329217&view=rev
Log:
rename a method s/Paramter/r/Parameter/

Modified:
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/deployment/DescriptionBuilder.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/AxisOperation.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/AxisService.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/AxisServiceGroup.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/HandlerDescription.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/ModuleConfiguration.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/ModuleDescription.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/ParameterInclude.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/ParameterIncludeImpl.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/TransportInDescription.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/TransportOutDescription.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/engine/AxisConfiguration.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/engine/AxisConfigurationImpl.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/storage/impl/AxisFileStorage.java
    webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/storage/impl/AxisMemoryStorage.java
    webservices/axis2/trunk/java/modules/core/test/org/apache/axis2/deployment/AxisObserverImpl.java

Modified: webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/deployment/DescriptionBuilder.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/deployment/DescriptionBuilder.java?rev=329217&r1=329216&r2=329217&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/deployment/DescriptionBuilder.java (original)
+++ webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/deployment/DescriptionBuilder.java Fri Oct 28 07:41:32 2005
@@ -222,7 +222,7 @@
                 String lockedValue = paraLocked.getAttributeValue();
                 if("true".equals(lockedValue)){
                     //if the parameter is locked at some levle paramer value replace by that
-                    if(parent!=null && parent.isParamterLocked(parameter.getName())){
+                    if(parent!=null && parent.isParameterLocked(parameter.getName())){
                         throw new DeploymentException(Messages.getMessage(
                                 DeploymentErrorMsgs.CONFIG_NOT_FOUND,parameter.getName()));
                     } else{
@@ -240,7 +240,7 @@
             }
             try {
                 if(parent !=null){
-                    if(parentpara == null | !parent.isParamterLocked(parameter.getName())){
+                    if(parentpara == null | !parent.isParameterLocked(parameter.getName())){
                         parameterInclude.addParameter(parameter);
                     }
                 } else {

Modified: webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/AxisOperation.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/AxisOperation.java?rev=329217&r1=329216&r2=329217&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/AxisOperation.java (original)
+++ webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/AxisOperation.java Fri Oct 28 07:41:32 2005
@@ -169,7 +169,7 @@
         if (param == null) {
             return;
         }
-        if(isParamterLocked(param.getName())){
+        if(isParameterLocked(param.getName())){
             throw new AxisFault("Parmter is locked can not overide: " + param.getName());
         } else{
             ParameterIncludeImpl paramInclude = (ParameterIncludeImpl) this
@@ -307,11 +307,11 @@
     }
 
     //to check whether a given paramter is locked
-    public boolean isParamterLocked(String paramterName) {
+    public boolean isParameterLocked(String paramterName) {
         // checking the locked value of parent
         boolean loscked =  false;
         if (getParent() !=null) {
-            loscked=    getParent().isParamterLocked(paramterName);
+            loscked=    getParent().isParameterLocked(paramterName);
         }
         if(loscked){
             return true;

Modified: webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/AxisService.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/AxisService.java?rev=329217&r1=329216&r2=329217&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/AxisService.java (original)
+++ webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/AxisService.java Fri Oct 28 07:41:32 2005
@@ -19,7 +19,6 @@
 import com.ibm.wsdl.extensions.soap.SOAPAddressImpl;
 import com.ibm.wsdl.extensions.soap.SOAPConstants;
 import org.apache.axis2.AxisFault;
-import org.apache.axis2.Constants;
 import org.apache.axis2.context.MessageContext;
 import org.apache.axis2.context.ServiceContext;
 import org.apache.axis2.engine.AxisConfiguration;
@@ -366,7 +365,7 @@
             return;
         }
 
-        if(isParamterLocked(param.getName())){
+        if(isParameterLocked(param.getName())){
             throw new AxisFault("Parmter is locked can not overide: " + param.getName());
         } else{
             ParameterIncludeImpl paramInclude =
@@ -802,12 +801,12 @@
     }
 
     //to check whether a given paramter is locked
-    public boolean isParamterLocked(String paramterName) {
+    public boolean isParameterLocked(String paramterName) {
         // checking the locked value of parent
         boolean loscked = false;
 
         if (getParent() !=null) {
-            loscked =  getParent().getAxisDescription().isParamterLocked(paramterName);
+            loscked =  getParent().getAxisDescription().isParameterLocked(paramterName);
         }
         if(loscked){
             return true;

Modified: webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/AxisServiceGroup.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/AxisServiceGroup.java?rev=329217&r1=329216&r2=329217&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/AxisServiceGroup.java (original)
+++ webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/AxisServiceGroup.java Fri Oct 28 07:41:32 2005
@@ -78,12 +78,12 @@
         return paramInclude.getParameters();
     }
 
-    public boolean isParamterLocked(String paramterName) {
+    public boolean isParameterLocked(String paramterName) {
         // checking the locked value of parent
         boolean loscked = false;
 
         if (getParent() !=null) {
-            loscked =  getParent().isParamterLocked(paramterName);
+            loscked =  getParent().isParameterLocked(paramterName);
         }
         if(loscked){
             return true;

Modified: webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/HandlerDescription.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/HandlerDescription.java?rev=329217&r1=329216&r2=329217&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/HandlerDescription.java (original)
+++ webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/HandlerDescription.java Fri Oct 28 07:41:32 2005
@@ -107,7 +107,7 @@
      * @param param
      */
     public void addParameter(Parameter param) throws AxisFault{
-        if(isParamterLocked(param.getName())){
+        if(isParameterLocked(param.getName())){
             throw new AxisFault("Parmter is locked can not overide: " + param.getName());
         } else{
             parameterInclude.addParameter(param);
@@ -127,13 +127,13 @@
     }
 
     //to check whether the paramter is locked at any levle
-    public boolean isParamterLocked(String paramterName) {
+    public boolean isParameterLocked(String paramterName) {
         if(parent != null){
-            if(parent.isParamterLocked(paramterName)){
+            if(parent.isParameterLocked(paramterName)){
                 return true;
             }
         }
-        return parameterInclude.isParamterLocked(paramterName);
+        return parameterInclude.isParameterLocked(paramterName);
     }
 
     /**

Modified: webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/ModuleConfiguration.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/ModuleConfiguration.java?rev=329217&r1=329216&r2=329217&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/ModuleConfiguration.java (original)
+++ webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/ModuleConfiguration.java Fri Oct 28 07:41:32 2005
@@ -49,7 +49,7 @@
     }
 
     public void addParameter(Parameter param) throws AxisFault {
-        if(isParamterLocked(param.getName())){
+        if(isParameterLocked(param.getName())){
             throw new AxisFault("Parmter is locked can not overide: " + param.getName());
         } else{
             paramterinclude.addParameter(param);
@@ -64,11 +64,11 @@
         return paramterinclude.getParameters();
     }
 
-    public boolean isParamterLocked(String paramterName) {
+    public boolean isParameterLocked(String paramterName) {
         // checking the locked value of parent
         boolean loscked =  false;
         if (parent !=null) {
-            loscked = parent.isParamterLocked(paramterName);
+            loscked = parent.isParameterLocked(paramterName);
         }
         if(loscked){
             return true;

Modified: webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/ModuleDescription.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/ModuleDescription.java?rev=329217&r1=329216&r2=329217&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/ModuleDescription.java (original)
+++ webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/ModuleDescription.java Fri Oct 28 07:41:32 2005
@@ -132,7 +132,7 @@
      * @param param
      */
     public void addParameter(Parameter param)throws AxisFault{
-        if(isParamterLocked(param.getName())){
+        if(isParameterLocked(param.getName())){
             throw new AxisFault("Parmter is locked can not overide: " + param.getName());
         } else{
             parameters.addParameter(param);
@@ -196,11 +196,11 @@
     }
 
     //to check whether a given paramter is locked
-    public boolean isParamterLocked(String paramterName) {
+    public boolean isParameterLocked(String paramterName) {
         // checking the locked value of parent
           boolean loscked =  false;
         if (getParent() !=null) {
-            loscked=    getParent().isParamterLocked(paramterName);
+            loscked=    getParent().isParameterLocked(paramterName);
         }
         if(loscked){
             return true;

Modified: webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/ParameterInclude.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/ParameterInclude.java?rev=329217&r1=329216&r2=329217&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/ParameterIncludeImpl.java (original)
+++ webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/ParameterIncludeImpl.java Fri Oct 28 07:41:32 2005
@@ -69,7 +69,7 @@
     }
 
     //to check whether the paramter is locked at any levle
-    public boolean isParamterLocked(String paramterName) {
+    public boolean isParameterLocked(String paramterName) {
         return false;
     }
 }

Modified: webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/TransportInDescription.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/TransportInDescription.java?rev=329217&r1=329216&r2=329217&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/TransportInDescription.java (original)
+++ webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/TransportInDescription.java Fri Oct 28 07:41:32 2005
@@ -89,8 +89,8 @@
     }
 
     //to check whether the paramter is locked at any levle
-    public boolean isParamterLocked(String paramterName) {
-        return paramInclude.isParamterLocked(paramterName);
+    public boolean isParameterLocked(String paramterName) {
+        return paramInclude.isParameterLocked(paramterName);
     }
 
     /**

Modified: webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/TransportOutDescription.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/TransportOutDescription.java?rev=329217&r1=329216&r2=329217&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/TransportOutDescription.java (original)
+++ webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/TransportOutDescription.java Fri Oct 28 07:41:32 2005
@@ -83,8 +83,8 @@
     }
 
     //to check whether the paramter is locked at any levle
-    public boolean isParamterLocked(String paramterName) {
-        return paramInclude.isParamterLocked(paramterName);
+    public boolean isParameterLocked(String paramterName) {
+        return paramInclude.isParameterLocked(paramterName);
     }
 
     /**

Modified: webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/engine/AxisConfiguration.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/engine/AxisConfiguration.java?rev=329217&r1=329216&r2=329217&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/engine/AxisConfiguration.java (original)
+++ webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/engine/AxisConfiguration.java Fri Oct 28 07:41:32 2005
@@ -142,7 +142,7 @@
     public AxisStorage getAxisStorage();
 
     //to check whether a given paramter is locked
-    public boolean isParamterLocked(String paramterName);
+    public boolean isParameterLocked(String paramterName);
 
     public AxisServiceGroup getServiceGroup(String serviceNameAndGroupString);
 

Modified: webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/engine/AxisConfigurationImpl.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/engine/AxisConfigurationImpl.java?rev=329217&r1=329216&r2=329217&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/engine/AxisConfigurationImpl.java (original)
+++ webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/engine/AxisConfigurationImpl.java Fri Oct 28 07:41:32 2005
@@ -332,7 +332,7 @@
     }
 
     //to check whether a given paramter is locked
-    public boolean isParamterLocked(String paramterName) {
+    public boolean isParameterLocked(String paramterName) {
         Parameter parameter = getParameter(paramterName);
         return parameter != null && parameter.isLocked();
     }
@@ -418,7 +418,7 @@
      * @param param
      */
     public void addParameter(Parameter param) throws AxisFault{
-        if(isParamterLocked(param.getName())){
+        if(isParameterLocked(param.getName())){
             throw new AxisFault("Parmter is locked can not overide: " + param.getName());
         } else{
             paramInclude.addParameter(param);

Modified: webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/storage/impl/AxisFileStorage.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/storage/impl/AxisFileStorage.java?rev=329217&r1=329216&r2=329217&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/storage/impl/AxisFileStorage.java (original)
+++ webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/storage/impl/AxisFileStorage.java Fri Oct 28 07:41:32 2005
@@ -118,7 +118,7 @@
     }
 
     //to check whether the paramter is locked at any levle
-    public boolean isParamterLocked(String paramterName) {
-        return paramter.isParamterLocked(paramterName);
+    public boolean isParameterLocked(String paramterName) {
+        return paramter.isParameterLocked(paramterName);
     }
 }

Modified: webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/storage/impl/AxisMemoryStorage.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/storage/impl/AxisMemoryStorage.java?rev=329217&r1=329216&r2=329217&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/storage/impl/AxisMemoryStorage.java (original)
+++ webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/storage/impl/AxisMemoryStorage.java Fri Oct 28 07:41:32 2005
@@ -75,8 +75,8 @@
     }
 
     //to check whether the paramter is locked at any levle
-    public boolean isParamterLocked(String paramterName) {
-        return paramter.isParamterLocked(paramterName);
+    public boolean isParameterLocked(String paramterName) {
+        return paramter.isParameterLocked(paramterName);
     }
 
 }

Modified: webservices/axis2/trunk/java/modules/core/test/org/apache/axis2/deployment/AxisObserverImpl.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/core/test/org/apache/axis2/deployment/AxisObserverImpl.java?rev=329217&r1=329216&r2=329217&view=diff
==============================================================================
--- webservices/axis2/trunk/java/modules/core/test/org/apache/axis2/deployment/AxisObserverImpl.java (original)
+++ webservices/axis2/trunk/java/modules/core/test/org/apache/axis2/deployment/AxisObserverImpl.java Fri Oct 28 07:41:32 2005
@@ -48,7 +48,7 @@
     }
 
     //to check whether the paramter is locked at any levle
-    public boolean isParamterLocked(String paramterName) {
+    public boolean isParameterLocked(String paramterName) {
         return false;
     }
 }
--- webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/ParameterInclude.java (original)
+++ webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/ParameterInclude.java Fri Oct 28 07:41:32 2005
@@ -48,7 +48,10 @@
      */
     ArrayList getParameters();
 
-    //to check whether the paramter is locked at any levle
-    boolean isParamterLocked(String paramterName);
+    /**
+     * to check whether the parameter is locked at any level 
+     */
+
+    boolean isParameterLocked(String paramterName);
 
 }

Modified: webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/ParameterIncludeImpl.java
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/java/modules/core/src/org/apache/axis2/description/ParameterIncludeImpl.java?rev=329217&r1=329216&r2=329217&view=diff
==============================================================================